#include <string>
#include <iostream>
#include "TSeries.hh"
#include "FSeries.hh" 
#include "FSpectrum.hh" 
#include "DatEnv.hh" 
#include "MonServer.hh"  // Include Monitor Data API 

const char* const SpectrumMonitorName = "SpectrumMonitor";

class SpectrumMonitor : public DatEnv, MonServer { 
   // inherit from DatEnv and MonServer 
   public: 
      SpectrumMonitor (int argc, const char* argv[]); 
      virtual ~SpectrumMonitor() {} 
      virtual void ProcessData(); 
      virtual void Attention() { 
         // This call serves data, if a request is pending 
         MonServer::Attention(); } 
   private: 
      TSeries*     fData;      // Input data 
      FSpectrum    fSpectrum;  // Data object to be exported 
}; 

EXECDAT (SpectrumMonitor);   // DMT Framework 

// Constructs the monitor, initializes the monitor server and subscribes
// the data objects 
SpectrumMonitor::SpectrumMonitor (int argc, const char* argv[]) 
: DatEnv (argc, argv), MonServer (SpectrumMonitorName), fData (0) 
{
   if ((argc <= 1) || (argv[1] == "-h") || (argv[argc-1][0] == '-')) {
      cout << "usage: mon_example 'channel name'" << endl;
      finish();
   }
   else {
      // Monitor name used by the name server 
      getDacc().addChannel (argv[argc-1], 1, &fData); 
      // subscribe the data object 
      serveData (argv[argc-1], &fSpectrum); 
   }
} 

// Get some data and load the history buffer 
void SpectrumMonitor::ProcessData() 
{ 
   // Calculate the power spectrum 
   if (fData) {
      FSeries* fft = new FSeries (*fData); 
      fSpectrum = FSpectrum (*fft); 
      delete fft;
   }
}
