#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: VOID Cont_setup(conptr) - Initialize continuity	*
 *----------------------------------------------------------------------*
 *	Arguments:	struct con_sto *contin - pointer to the 	*
 *			 continuity info (data from the previous run)	*
 *----------------------------------------------------------------------*
 *	Returns:	Nothing (VOID)					*
 *----------------------------------------------------------------------*
 *	Fatal Errors:	This routine does not have fatal exits		*
 *----------------------------------------------------------------------*
 *	This routine initializes parameters on the first pass.		*
 *	In particular, the routine sets itc to a value greater than	*
 *	zero so that E_detect returns true during the initilization	*
 *	process.  If one expects to change the sample rate during the	*
 *	processing, Main should call this routine to reinitialize the	*
 *	parameters.							*
 *----------------------------------------------------------------------*/

VOID Cont_setup(contin)
register struct con_sto *contin;

{
        LONG i;	

	contin->last_x = 0;		/* initialize for P_one */
	contin->rec_last_x = 0; 	/* initialize for P_one */
	contin->sum_s_c = 0;		/* initialize for P_one */
	contin->s_sum_sc = 0; 		/* initialize for P_one */
	contin->evon = FALSE; 		/* initialize for Event */
	contin->epf = FALSE; 		/* initialize for Event */
	contin->fst_flg = 0; 		/* initialize for Event */
	contin->index = 0; 		/* initialize for P_one */
	contin->kk = 0;  		/* initialize for P_two */
	contin->jj = 0; 		/* initialize for Event */

	contin->prev_slope = 2;  	/* initialize for P_one */
	contin->s_amp = 600000;  	/* initialize for P_one */
	contin->last_y = 0; 		/* initialize for P_one */
	contin->maxamp = 0;		/* initialize for P_one */
	contin->max_y = 0;		/* initialize for P_one */                  

/*-----------Set the thresholds high enough to suppress retriggers------*/
/*			in the initialization process			*/

	contin->th1 = 500000; 
	contin->th2 = 500000; 
	contin->th3 = 500000;

/*----------------Ensure that the thresholds will remain high ---------*/
/*		   during the initialization process. See P_two, Xth. 	*/

	contin->twosd = 300000; 
	contin->thx = contin->twosd <<1;
#ifndef RAMPUP
	for(i = 0;i < 16;i++) contin->tsstak[i] = 1000000;
#else
	for(i = 0;i < 16;i++) contin->tsstak[i] = 0;
#endif

/*---------------Initialize the buffers for Event----------------------*/

	for(i = 0;i < 4; i++) { 
		contin->abuf_sc[i] = contin->abuf_tim[i] = 0;
		contin->abuf_amp[i] = 0;
	}
	for(i = 0;i < E_B; i++) { 
		contin->buf_flg[i] = contin->buf_sc[i] = 0;
		contin->buf_tim[i] = 0;
		contin->buf_amp[i] = 0;
	}

	contin->itc = NOR_OUT;

/*-----------------------Defaults for onset processing---------------------*/

#ifdef NOPONSET
	contin->ponset=FALSE;	/* No output on standard out */
#else
	contin->ponset=TRUE;	/* Output on standard out */
#endif

	contin->onsproc=NULL;	/* No auxillarly output */
	
	return;
}
