#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: VOID Count_dn() - Count Down Interval of Event	*
 *----------------------------------------------------------------------*
 *	Arguments:	No arguments					*
 *----------------------------------------------------------------------*
 *	Returns:	Nothing (VOID)					*
 *----------------------------------------------------------------------*
 *	Fatal Errors:	This routine does not have fatal exits		*
 *----------------------------------------------------------------------*
 *      As implemented here, to inhibit multiple printouts immediately	*
 *	 after a detection, the detector is disabled for (NOR_OUT -	*
 *	 EV_OFF) x wait_blk samples and then reenabled.  The interval	* 
 *	 of the event is NOR_OUT x wait_blk samples.			*
 *----------------------------------------------------------------------*/

VOID Count_dn()
{
	if(con_ptr->itc > 0) {	/* itc was set to NOR_OUT in Ibingo */
		if(++con_ptr->nn >= con_ptr->wait_blk) {  /* increment nn */ 
			con_ptr->nn = 0;
			con_ptr->itc--;	/* decrement wait-block counter */     
		}
	}

			/* enable detecting events */
	if(con_ptr->itc <= EV_OFF) con_ptr->evon = FALSE;

	return;
}


#ifdef JNMCOMMENT
/*************************************************************************

			EXPLANATION OF VARIABLES

	EV_OFF  -- controls the interval in which events are 
		    detected in the P coda. Typical value = 2.
		    To enable detections throughout the P coda,
		    set EV_OFF = NOR_OUT.  To completely disable
		    detections and recomputation of thresholds in
		    the P coda, set EV_OFF = 0.  0 <= EV_OFF <= NOR_OUT.

	evon	-- the event on flag.  While evon=TRUE, events are
		    not detected and P_two is not called (thresholds
		    are not computed). We want to inhibit detections
		    in the P_coda to suppress spurious printouts by
		    Onset.

	itc	-- counter for the interval of the event.  Set = NOR_OUT
		    in Ibingo and Pass_one.  When itc = 0, the interval
		    of the event is terminated.

	nn	-- counter for itc.

	wait_blk-- wait block. The variable itc is a factor of wait_blk.
		    The interval of the event is NOR_OUT x wait_blk.  
		    Because we envision that data will be written to tape
		    during the interval of the event, wait_blk typically is
		    chosen a function of the input record length.

**************************************************************************/
#endif
